@@ -1,10 +1,5 @@
 package DBIx::Class::Row::Delta;
-BEGIN {  ## no critic (RequireUseStrict, RequireUseWarnings)
-  $DBIx::Class::Row::Delta::VERSION = '0.0.4'; ## no critic (RequireUseStrict, RequireUseWarnings)
-}
-BEGIN {  ## no critic (RequireUseStrict, RequireUseWarnings)
-  $DBIx::Class::Row::Delta::DIST = 'DBIx-Class-Row-Delta';  ## no critic (RequireUseStrict, RequireUseWarnings)
-}
+$DBIx::Class::Row::Delta::VERSION = '0.0.5';
 use Moose;
 
 =head1 NAME
